@@ -234,7 +234,7 @@ instruments <- function() {
   # TODO: Find a way to automate this - maybe data$results minus example data?
 
   cat(
-    "The circumplex package currently includes 12 instruments:\n",
+    "The circumplex package currently includes 13 instruments:\n",
     "1. CSIE: Circumplex Scales of Interpersonal Efficacy (csie)\n",
     "2. CSIG: Circumplex Scales of Intergroup Goals (csig)\n",
     "3. CSIP: Circumplex Scales of Interpersonal Problems (csip)\n",
@@ -245,8 +245,9 @@ instruments <- function() {
     "8. IIP-SC: Inventory of Interpersonal Problems, Short Circumplex (iipsc)\n",
     "9. IIS-32: Inventory of Interpersonal Strengths, Brief Version (iis32)\n",
     "10. IIS-64: Inventory of Interpersonal Strengths (iis64)\n",
-    "11. IPIP-IPC: IPIP Interpersonal Circumplex (ipipipc)\n",
-    "12. ISC: Interpersonal Sensitivities Circumplex (isc)\n"
+    "11. IIT-C: Inventory of Influence Tactics Circumplex (iitc)\n",
+    "12. IPIP-IPC: IPIP Interpersonal Circumplex (ipipipc)\n",
+    "13. ISC: Interpersonal Sensitivities Circumplex (isc)\n"
   )
 }
 
@@ -272,9 +273,9 @@ instruments <- function() {
 #' instrument("iip32")
 #' x <- instrument(iip32)
 instrument <- function(code) {
-  name_en <- rlang::enquo(code)
-  assert_that(is_enquo(name_en))
-  name_str <- rlang::quo_name(name_en)
+  code <- rlang::enquo(code)
+  assert_that(is_provided(code))
+  name_str <- rlang::quo_name(code)
   utils::data(list = name_str)
   invisible(get(name_str))
 }
